function movements = get_hand_movement(id,f,m) 
% function movements = get_hand_movement(id,f,m) 
% Returns the Hand and Body Movement Patterns
% id = participant id
% f = 0 for participants that did not receive feedback and 1 for participants
% that received feedback
% m = 0 for standing and 1 for mobile patterns 
% The data returned are organized according to the stimuli array
% For each rwo of this array 8 movement patterns were obtained 
% 4 for standing and 4 for mobile participants
% movements is a cell array with 8 columnds, 
% movement_data | stimulus | movement_data_stimulus | ....


load stimuli;
data = [];positions = [];

file_name = sprintf('C:\\exp_data\\movement\\user_%d\\user_%d_trial_history_m%d_f%d.txt',id,id,m,f);
trial_history = dlmread(file_name);
[Y,I]=sort(trial_history(:,2));new_history = [];
new_history(:,2)=Y;
new_history(:,3)=trial_history(I,3);
new_history(:,1)=trial_history(I,1);
    
[data_hand,data_body] = get_move_data(id,f,m);

tm_h = find(data_hand(:,3)==-1000); tm_h = [0;tm_h]; j = 1;

for i=1:(length(tm_h)-1)
    if (tm_h(i+1)-tm_h(i)>1)
        new_data_hand{j} = data_hand((tm_h(i)+1):(tm_h(i+1)-1),3);
        j=j+1;
    end
end

tm_b = find(data_body(:,3)==-1000); tm_b = [0;tm_b]; j = 1;

for i=1:(length(tm_b)-1)
    if (tm_b(i+1)-tm_b(i)>1)
        new_data_body{j} = data_body((tm_b(i)+1):(tm_b(i+1)-1),3);
        
        j=j+1;
    end
end

movements = cell(size(stimuli,1),8);
for i=1:size(trial_history,1) 
    if length(new_data_body{i})<=length(new_data_hand{i}) 
        hand_angle = get_hand_angle(new_data_hand{i}(1:length(new_data_body{i})),new_data_body{i});    
    else
        hand_angle = get_hand_angle(new_data_hand{i},new_data_body{i}(1:length(new_data_hand{i})));
    end
    
    J1 = find( trial_history(i,1) == stimuli(:,2) );
    J2 = find( trial_history(i,2) == stimuli(:,1) );
    J = intersect(J1,J2);
    if ~isempty(J)
        for j = 1:8
            if isempty(movements{J,j})
                movements{J,j} = hand_angle;
                movements{J,j+1} = trial_history(i,:);
            end
        end
    end
end
